/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.bind;

import net.lucubrators.honeycomb.core.bind.exceptions.UnknownBinderException;

/**
 * Provides Binders
 * 
 * @author aglomann
 */
public interface BinderProvider {

	/**
	 * @param id
	 *            id which maps to the wanted Binder
	 * @return the binder object if one was found. Never null.
	 * @throws UnknownBinderException
	 *             if no binder is mapped.
	 */
	Object getBinder(String id) throws UnknownBinderException;

	/**
	 * adds binders to the provider
	 * 
	 * @param id
	 *            the id to which the binder will be mapped
	 * @param binder
	 *            an objects which implements a method annotated with
	 *            {@link Binder}
	 */
	void addBinder(String id, Object binder);

}
