/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.controller;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import net.lucubrators.honeycomb.core.bind.Binder;
import net.lucubrators.honeycomb.core.shared.Model;
import net.lucubrators.honeycomb.core.shared.annotations.CombAttribute;
import net.lucubrators.honeycomb.core.shared.annotations.CombAttributes;
import net.lucubrators.honeycomb.core.shared.annotations.Param;

/**
 * Indicates that the method will return an object which populates a form or
 * will be populated by a form. When a method with this annotation returns null,
 * it tells the engine that the response was already handled and the engine
 * stops processing.
 * 
 * Methods with this annotation must be capable of the following argument types
 * 
 * <ul>
 * <li>ServletRequest</li>
 * <li>ServletResponse</li>
 * <li> {@link Param}</li>
 * <li> {@link CombAttribute}</li>
 * <li> {@link CombAttributes}</li>
 * <li> {@link Model}</li>
 * </ul>
 * 
 * Further argument types could be possible. Refer to the implementation for
 * more details.
 * 
 * @author aglomann
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.METHOD })
public @interface FormObjectProvider {

	/**
	 * @return the name of the form object. The form object should be implicitly
	 *         added to the model under this name.
	 */
	String name();

	/**
	 * 
	 * @return property names of the form object which should not be populated
	 *         by a {@link Binder} or {@link HandleEvent}
	 */
	String[] dontBind() default {};

	/**
	 * 
	 * @return The id of the binder who should bind request values to the
	 *         formobject
	 */
	String binder();
}
