/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.engine;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.lucubrators.honeycomb.core.Comb;
import net.lucubrators.honeycomb.core.constraint.Constraint;
import net.lucubrators.honeycomb.core.constraint.ConstraintHolder;
import net.lucubrators.honeycomb.core.controller.FormObjectHolder;
import net.lucubrators.honeycomb.core.controller.FormObjectProvider;
import net.lucubrators.honeycomb.core.messages.Messages;
import net.lucubrators.honeycomb.core.shared.Model;

/**
 * Container Object for possible bindable values
 * 
 * @author aglomann
 */
public class Bindables {

	private HttpServletRequest	request;
	private HttpServletResponse	response;
	private Map<String, String>	combAttributes;
	private FormObjectHolder	formObject;
	private Model				model;
	private ConstraintHolder	constraintHolder;
	private Messages			messages;

	/**
	 * @param request
	 *            the current HttpServletRequest
	 */
	public void setRequest(final HttpServletRequest request) {
		this.request = request;
	}

	/**
	 * @param aResponse
	 *            the current HttpServletResponse
	 */
	public void setResponse(final HttpServletResponse aResponse) {
		this.response = aResponse;
	}

	/**
	 * @return the current HttpServletRequest set or null
	 */
	public HttpServletRequest getRequest() {
		return request;
	}

	/**
	 * @return the current HttpServletResponse set or null
	 */
	public HttpServletResponse getResponse() {
		return response;
	}

	/**
	 * @param combAttributes
	 *            attributes of the currently processed {@link Comb}
	 */
	public void setCombAttributes(final Map<String, String> combAttributes) {
		this.combAttributes = combAttributes;
	}

	/**
	 * @return attributes of the currently processed {@link Comb} set or null
	 */
	public Map<String, String> getCombAttributes() {
		return combAttributes;
	}

	/**
	 * @return the {@link FormObjectHolder} containing the form object provided
	 *         by {@link FormObjectProvider} and its errors
	 */
	public FormObjectHolder getFormObjectHolder() {
		return formObject;
	}

	/**
	 * @param formObject
	 *            the {@link FormObjectHolder} of the current {@link Comb} if a
	 *            form object is provided by {@link FormObjectProvider}
	 */
	public void setFormObjectHolder(final FormObjectHolder formObject) {
		this.formObject = formObject;
	}

	/**
	 * @param model
	 *            the model of the current {@link Comb}
	 */
	public void setModel(final Model model) {
		this.model = model;
	}

	/**
	 * @return the model of the currently processed {@link Comb}
	 */
	public Model getModel() {
		return model;
	}

	/**
	 * @return the {@link ConstraintHolder} which holds the current
	 *         {@link Constraint} method to be called
	 */
	public ConstraintHolder getConstraintHolder() {
		return constraintHolder;
	}

	/**
	 * @param constraintHolder
	 *            the {@link ConstraintHolder} which holds the current
	 *            {@link Constraint} method to be called
	 */
	public void setConstraintHolder(final ConstraintHolder constraintHolder) {
		this.constraintHolder = constraintHolder;
	}

	/**
	 * 
	 * @return messages bindable by this comb.
	 */
	public Messages getMessages() {
		return messages;
	}

	/**
	 * Set the messages object which should be populated by the current comb.
	 * 
	 * @param messages
	 */
	public void setMessages(final Messages messages) {
		this.messages = messages;
	}

}
