/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.engine;

import javax.servlet.http.HttpServletRequest;

import net.lucubrators.honeycomb.core.bind.Binder;
import net.lucubrators.honeycomb.core.reflect.exceptions.CombInvocationException;

/**
 * interface representing the caller of a binder method.
 * 
 * @author gnalFF
 * 
 */
public interface BinderMethodInvoker {

	/**
	 * method which should invoke the method in a Binder which is annotated with
	 * {@link Binder}. The method has no return value since the reason of a
	 * binder is to populate a form object by the current
	 * {@link HttpServletRequest}'s paramteres.
	 * 
	 * @param binder
	 *            the object holding the binder method.
	 * @param bindables
	 *            the current {@link Bindables} object
	 * @throws CombInvocationException
	 *             if an exception occurs while invoking the binder method. The
	 *             cause of this exception should hold the exception thrown by
	 *             the binder's method.
	 */
	public void invokeBinder(Object binder, Bindables bindables) throws CombInvocationException;

}
