/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.engine;

import net.lucubrators.honeycomb.core.constraint.Constraint;
import net.lucubrators.honeycomb.core.reflect.exceptions.CombInvocationException;

/**
 * Interface representing the caller of a method annotated with
 * {@link Constraint}
 * 
 * @author gnalFF
 * 
 */
public interface ConstraintInvoker {
	/**
	 * This method should call the method of a Constraint which is annotated
	 * with {@link Constraint}.
	 * 
	 * @param constraint
	 *            the Object holding the constraint method.
	 * @param bindables
	 *            the current {@link Bindables} object
	 * @return the result of the invoked method.
	 * @throws CombInvocationException
	 *             if the called method fails this exception should hold the
	 *             reason as cause.
	 */
	Object invokeConstraint(Object constraint, Bindables bindables) throws CombInvocationException;
}