/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.messages;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * This class can collect all types of messages
 * 
 * @author gnalFF
 * 
 */
public final class Messages {

	private final HashMap<MessageLevel, List<Message>>	messagesByLevel;

	/**
	 * Constructor
	 */
	public Messages() {
		messagesByLevel = new HashMap<MessageLevel, List<Message>>();
	}

	/**
	 * Adds a message
	 * 
	 * @param message
	 *            the message to add
	 */
	public void addMessage(final Message message) {
		MessageLevel messageLevel = message.getMessageLevel();
		if (!messagesByLevel.containsKey(messageLevel)) {
			ArrayList<Message> messages = new ArrayList<Message>();
			messagesByLevel.put(messageLevel, messages);
		}
		messagesByLevel.get(messageLevel).add(message);
	}

	/**
	 * 
	 * @param level
	 *            the {@link MessageLevel} to filter
	 * @return a list of messages with the desired {@link MessageLevel}, never
	 *         null
	 */
	public List<Message> getMessagesByLevel(final MessageLevel level) {
		List<Message> list = messagesByLevel.get(level);
		if (list == null) {
			list = new ArrayList<Message>();
		}
		return list;
	}

	/**
	 * 
	 * @return all messages added. Removing or adding Messages has no effect
	 *         since the returned List is not backed by this class
	 */
	public List<Message> getAllMessages() {
		ArrayList<Message> ret = new ArrayList<Message>();
		for (List<Message> typeMessages : messagesByLevel.values()) {
			ret.addAll(typeMessages);
		}
		return ret;
	}
}
