/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.shared;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.Map.Entry;

/**
 * The Model to be popultated for the view
 * 
 * @author gnalFF
 * 
 */
public class Model {

	private HashMap<String, Object>	model;

	public Model() {
		model = new HashMap<String, Object>();
	}

	/**
	 * Puts an attribute to the view
	 * 
	 * @param key
	 *            the key under which the value is stored
	 * @param value
	 *            the attribute value
	 */
	public void put(String key, Object value) {
		model.put(key, value);
	}

	/**
	 * Puts a bunch of attributes to the model.
	 * 
	 * @param map
	 *            a map containing attribute keys and values.
	 */
	public void putAll(Map<? extends String, ? extends Object> map) {
		model.putAll(map);
	}

	/**
	 * Get an attribute from the model.
	 * 
	 * @param key
	 *            the key of the attribute
	 * @return the value stored under the given key or null.
	 */
	public Object get(String key) {
		return model.get(key);
	}

	/**
	 * Checks if an attribute exists
	 * 
	 * @param key
	 *            the key to look up
	 * @return true if the key exisits.
	 */
	public boolean containsKey(String key) {
		return model.containsKey(key);
	}

	/**
	 * removes an attribute from the model.
	 * 
	 * @param key
	 *            the key to be removed.
	 */
	public void remove(String key) {
		model.remove(key);
	}

	/**
	 * @return the number of all items in the model.
	 */
	public int size() {
		return model.size();
	}

	/**
	 * @return the entryset of the model.
	 */
	public Set<Entry<String, Object>> entrySet() {
		return model.entrySet();
	}

}
