/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.util;

import javax.servlet.http.HttpServletRequest;

import net.lucubrators.honeycomb.core.controller.ControllerResult;

/**
 * A util class for the controller results
 * 
 * @author gnalFF
 * 
 */
public final class ControllerResultUtil {

	/**
	 * Returns the controller result currently processed. Note: the current
	 * results needs to be set manually to the request.
	 * 
	 * @param request
	 *            the current {@link HttpServletRequest}
	 * @return the result stored in the current {@link HttpServletRequest}
	 */
	public static ControllerResult getCurrentResult(HttpServletRequest request) {
		return (ControllerResult) request.getAttribute(ControllerResult.REQUEST_ATTRIBUTE_KEY);
	}

	/**
	 * Saves the {@link ControllerResult} currently in process to the
	 * {@link HttpServletRequest}
	 * 
	 * @param request
	 *            the current {@link HttpServletRequest}
	 * @param result
	 *            the current {@link ControllerResult}
	 * @return the result previously stored in the request.
	 */
	public static ControllerResult setCurrentResult(HttpServletRequest request, ControllerResult result) {
		ControllerResult previousResult = (ControllerResult) request.getAttribute(ControllerResult.REQUEST_ATTRIBUTE_KEY);
		request.setAttribute(ControllerResult.REQUEST_ATTRIBUTE_KEY, result);
		return previousResult;
	}

}
