/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.util;

import javax.servlet.http.HttpServletRequest;

import net.lucubrators.honeycomb.core.engine.exceptions.UnsupportedRequestMethodException;

/**
 * An enum which mapps to a <b>supported</b> request methods
 * 
 * @author gnalFF
 * 
 */
public enum RequestMethod {

	/**
	 * Maps to the request method: get
	 */
	GET,
	/**
	 * Maps to the reqeust method: post
	 */
	POST;

	/**
	 * Maps a request to a RequestMethod
	 * 
	 * @param request
	 *            the current {@link HttpServletRequest}
	 * @return a {@link RequestMethod} which is mapped to the requests method
	 * @throws UnsupportedRequestMethodException
	 *             if the request has no supported reqeust method
	 */
	public static RequestMethod resolveMethod(final HttpServletRequest request) throws UnsupportedRequestMethodException {
		String method = request.getMethod().toUpperCase();
		if (method.equals(GET.name())) {
			return GET;
		}
		if (method.equals(POST.name())) {
			return POST;
		}
		throw new UnsupportedRequestMethodException("Request method " + method + " not supported!");
	}

}
