/**
 * Copyright (c) 2010 Alois Glomann gnalff@lucubrators.net
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.lucubrators.honeycomb.core.view;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.lucubrators.honeycomb.core.controller.ControllerResult;

/**
 * ViewContext holds methods to render a view and additional informations
 * helping you to render a view.
 * 
 * @author gnalFF
 * 
 */
public interface ViewContext {

	/**
	 * includes e.g. a jsp.
	 * 
	 * @param path
	 *            the path of the jsp to be included
	 */
	void include(String path);

	/**
	 * Writes a plain string to the response.
	 * 
	 * @param toWrite
	 */
	void write(String toWrite);

	/**
	 * Returns the controller result belonging to this view.
	 * 
	 * @return
	 */
	ControllerResult getControllerResult();

	/**
	 * @return the current {@link HttpServletResponse}
	 */
	HttpServletResponse getResponse();

	/**
	 * @return the current {@link HttpServletRequest}
	 */
	HttpServletRequest getRequest();

}
